Class: Aws::PcaConnectorAd::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::PcaConnectorAd::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-pcaconnectorad/client.rb
Overview
An API client for PcaConnectorAd. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::PcaConnectorAd::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector between Amazon Web Services Private CA and an Active Directory.
-
#create_directory_registration(params = {}) ⇒ Types::CreateDirectoryRegistrationResponse
Creates a directory registration that authorizes communication between Amazon Web Services Private CA and an Active Directory.
-
#create_service_principal_name(params = {}) ⇒ Struct
Creates a service principal name (SPN) for the service account in Active Directory.
-
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates an Active Directory compatible certificate template.
-
#create_template_group_access_control_entry(params = {}) ⇒ Struct
Create a group access control entry.
-
#delete_connector(params = {}) ⇒ Struct
Deletes a connector for Active Directory.
-
#delete_directory_registration(params = {}) ⇒ Struct
Deletes a directory registration.
-
#delete_service_principal_name(params = {}) ⇒ Struct
Deletes the service principal name (SPN) used by a connector to authenticate with your Active Directory.
-
#delete_template(params = {}) ⇒ Struct
Deletes a template.
-
#delete_template_group_access_control_entry(params = {}) ⇒ Struct
Deletes a group access control entry.
-
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Lists information about your connector.
-
#get_directory_registration(params = {}) ⇒ Types::GetDirectoryRegistrationResponse
A structure that contains information about your directory registration.
-
#get_service_principal_name(params = {}) ⇒ Types::GetServicePrincipalNameResponse
Lists the service principal name that the connector uses to authenticate with Active Directory.
-
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Retrieves a certificate template that the connector uses to issue certificates from a private CA.
-
#get_template_group_access_control_entry(params = {}) ⇒ Types::GetTemplateGroupAccessControlEntryResponse
Retrieves the group access control entries for a template.
-
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors that you created by using the [docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector][1] action.
-
#list_directory_registrations(params = {}) ⇒ Types::ListDirectoryRegistrationsResponse
Lists the directory registrations that you created by using the [docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration][1] action.
-
#list_service_principal_names(params = {}) ⇒ Types::ListServicePrincipalNamesResponse
Lists the service principal names that the connector uses to authenticate with Active Directory.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags, if any, that are associated with your resource.
-
#list_template_group_access_control_entries(params = {}) ⇒ Types::ListTemplateGroupAccessControlEntriesResponse
Lists group access control entries you created.
-
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists the templates, if any, that are associated with a connector.
-
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
-
#update_template(params = {}) ⇒ Struct
Update template configuration to define the information included in certificates.
-
#update_template_group_access_control_entry(params = {}) ⇒ Struct
Update a group access control entry you created using [CreateTemplateGroupAccessControlEntry].
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2347 2348 2349 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2347 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2350 2351 2352 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2350 def errors_module Errors end |
Instance Method Details
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2320 2321 2322 2323 2324 2325 2326 2327 2328 2329 2330 2331 2332 2333 2334 2335 2336 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2320 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::PcaConnectorAd') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-pcaconnectorad' context[:gem_version] = '1.39.0' Seahorse::Client::Request.new(handlers, context) end |
#create_connector(params = {}) ⇒ Types::CreateConnectorResponse
Creates a connector between Amazon Web Services Private CA and an Active Directory. You must specify the private CA, directory ID, and security groups.
528 529 530 531 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 528 def create_connector(params = {}, = {}) req = build_request(:create_connector, params) req.send_request() end |
#create_directory_registration(params = {}) ⇒ Types::CreateDirectoryRegistrationResponse
Creates a directory registration that authorizes communication between Amazon Web Services Private CA and an Active Directory
571 572 573 574 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 571 def create_directory_registration(params = {}, = {}) req = build_request(:create_directory_registration, params) req.send_request() end |
#create_service_principal_name(params = {}) ⇒ Struct
Creates a service principal name (SPN) for the service account in Active Directory. Kerberos authentication uses SPNs to associate a service instance with a service sign-in account.
616 617 618 619 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 616 def create_service_principal_name(params = {}, = {}) req = build_request(:create_service_principal_name, params) req.send_request() end |
#create_template(params = {}) ⇒ Types::CreateTemplateResponse
Creates an Active Directory compatible certificate template. The connectors issues certificates using these templates based on the requester’s Active Directory group membership.
901 902 903 904 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 901 def create_template(params = {}, = {}) req = build_request(:create_template, params) req.send_request() end |
#create_template_group_access_control_entry(params = {}) ⇒ Struct
Create a group access control entry. Allow or deny Active Directory groups from enrolling and/or autoenrolling with the template based on the group security identifiers (SIDs).
955 956 957 958 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 955 def create_template_group_access_control_entry(params = {}, = {}) req = build_request(:create_template_group_access_control_entry, params) req.send_request() end |
#delete_connector(params = {}) ⇒ Struct
Deletes a connector for Active Directory. You must provide the Amazon Resource Name (ARN) of the connector that you want to delete. You can find the ARN by calling the
- docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_ListConnectors][1
-
action. Deleting a connector does not deregister your directory with Amazon Web Services Private CA. You can deregister your directory by calling the
995 996 997 998 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 995 def delete_connector(params = {}, = {}) req = build_request(:delete_connector, params) req.send_request() end |
#delete_directory_registration(params = {}) ⇒ Struct
Deletes a directory registration. Deleting a directory registration deauthorizes Amazon Web Services Private CA with the directory.
1023 1024 1025 1026 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1023 def delete_directory_registration(params = {}, = {}) req = build_request(:delete_directory_registration, params) req.send_request() end |
#delete_service_principal_name(params = {}) ⇒ Struct
Deletes the service principal name (SPN) used by a connector to authenticate with your Active Directory.
1060 1061 1062 1063 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1060 def delete_service_principal_name(params = {}, = {}) req = build_request(:delete_service_principal_name, params) req.send_request() end |
#delete_template(params = {}) ⇒ Struct
Deletes a template. Certificates issued using the template are still valid until they are revoked or expired.
1088 1089 1090 1091 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1088 def delete_template(params = {}, = {}) req = build_request(:delete_template, params) req.send_request() end |
#delete_template_group_access_control_entry(params = {}) ⇒ Struct
Deletes a group access control entry.
1120 1121 1122 1123 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1120 def delete_template_group_access_control_entry(params = {}, = {}) req = build_request(:delete_template_group_access_control_entry, params) req.send_request() end |
#get_connector(params = {}) ⇒ Types::GetConnectorResponse
Lists information about your connector. You specify the connector on input by its ARN (Amazon Resource Name).
1164 1165 1166 1167 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1164 def get_connector(params = {}, = {}) req = build_request(:get_connector, params) req.send_request() end |
#get_directory_registration(params = {}) ⇒ Types::GetDirectoryRegistrationResponse
A structure that contains information about your directory registration.
1203 1204 1205 1206 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1203 def get_directory_registration(params = {}, = {}) req = build_request(:get_directory_registration, params) req.send_request() end |
#get_service_principal_name(params = {}) ⇒ Types::GetServicePrincipalNameResponse
Lists the service principal name that the connector uses to authenticate with Active Directory.
1251 1252 1253 1254 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1251 def get_service_principal_name(params = {}, = {}) req = build_request(:get_service_principal_name, params) req.send_request() end |
#get_template(params = {}) ⇒ Types::GetTemplateResponse
Retrieves a certificate template that the connector uses to issue certificates from a private CA.
1430 1431 1432 1433 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1430 def get_template(params = {}, = {}) req = build_request(:get_template, params) req.send_request() end |
#get_template_group_access_control_entry(params = {}) ⇒ Types::GetTemplateGroupAccessControlEntryResponse
Retrieves the group access control entries for a template.
1474 1475 1476 1477 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1474 def get_template_group_access_control_entry(params = {}, = {}) req = build_request(:get_template_group_access_control_entry, params) req.send_request() end |
#list_connectors(params = {}) ⇒ Types::ListConnectorsResponse
Lists the connectors that you created by using the
- docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector][1
-
action.
[1]: docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateConnector
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1534 1535 1536 1537 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1534 def list_connectors(params = {}, = {}) req = build_request(:list_connectors, params) req.send_request() end |
#list_directory_registrations(params = {}) ⇒ Types::ListDirectoryRegistrationsResponse
Lists the directory registrations that you created by using the
- docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration][1
-
action.
[1]: docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1589 1590 1591 1592 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1589 def list_directory_registrations(params = {}, = {}) req = build_request(:list_directory_registrations, params) req.send_request() end |
#list_service_principal_names(params = {}) ⇒ Types::ListServicePrincipalNamesResponse
Lists the service principal names that the connector uses to authenticate with Active Directory.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1648 1649 1650 1651 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1648 def list_service_principal_names(params = {}, = {}) req = build_request(:list_service_principal_names, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags, if any, that are associated with your resource.
1678 1679 1680 1681 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1678 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_template_group_access_control_entries(params = {}) ⇒ Types::ListTemplateGroupAccessControlEntriesResponse
Lists group access control entries you created.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1737 1738 1739 1740 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1737 def list_template_group_access_control_entries(params = {}, = {}) req = build_request(:list_template_group_access_control_entries, params) req.send_request() end |
#list_templates(params = {}) ⇒ Types::ListTemplatesResponse
Lists the templates, if any, that are associated with a connector.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1935 1936 1937 1938 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1935 def list_templates(params = {}, = {}) req = build_request(:list_templates, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds one or more tags to your resource.
1965 1966 1967 1968 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1965 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes one or more tags from your resource.
1993 1994 1995 1996 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 1993 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_template(params = {}) ⇒ Struct
Update template configuration to define the information included in certificates.
2261 2262 2263 2264 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2261 def update_template(params = {}, = {}) req = build_request(:update_template, params) req.send_request() end |
#update_template_group_access_control_entry(params = {}) ⇒ Struct
Update a group access control entry you created using [CreateTemplateGroupAccessControlEntry].
2311 2312 2313 2314 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2311 def update_template_group_access_control_entry(params = {}, = {}) req = build_request(:update_template_group_access_control_entry, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2340 2341 2342 |
# File 'lib/aws-sdk-pcaconnectorad/client.rb', line 2340 def waiter_names [] end |