Class: Aws::PcaConnectorAd::Types::AccessControlEntry

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-pcaconnectorad/types.rb

Overview

An access control entry allows or denies Active Directory groups based on their security identifiers (SIDs) from enrolling and/or autoenrolling with the template.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#access_rightsTypes::AccessRights

Permissions to allow or deny an Active Directory group to enroll or autoenroll certificates issued against a template.



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The date and time that the Access Control Entry was created.



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#group_display_nameString

Name of the Active Directory group. This name does not need to match the group name in Active Directory.



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#group_security_identifierString

Security identifier (SID) of the group object from Active Directory. The SID starts with "S-".



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#template_arnString

The Amazon Resource Name (ARN) that was returned when you called CreateTemplate.



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The date and time that the Access Control Entry was updated.



51
52
53
54
55
56
57
58
59
60
# File 'lib/aws-sdk-pcaconnectorad/types.rb', line 51

class AccessControlEntry < Struct.new(
  :access_rights,
  :created_at,
  :group_display_name,
  :group_security_identifier,
  :template_arn,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end